@@ -3,13 +3,14 @@
 Copyright (c) IPython Development Team.
 Distributed under the terms of the Modified BSD License.
 
-This package provides a way to register a Kernel Comm implementation, as per the Jupyter kernel protocol.
+This package provides a way to register a Kernel Comm implementation, as per
+the Jupyter kernel protocol.
 It also provides a base Comm implementation and a default CommManager for the IPython case.
 """
 
-from .base_comm import CommManager
+from .base_comm import BaseComm, CommManager
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __all__ = [
     "create_comm",
     "get_comm_manager",
@@ -19,12 +20,17 @@ __all__ = [
 _comm_manager = None
 
 
+class DummyComm(BaseComm):
+    def publish_msg(self, msg_type, data=None, metadata=None, buffers=None, **keys):
+        pass
+
+
 def _create_comm(*args, **kwargs):
     """Create a Comm.
 
     This method is intended to be replaced, so that it returns your Comm instance.
     """
-    raise NotImplementedError("Cannot ")
+    return DummyComm(*args, **kwargs)
 
 
 def _get_comm_manager():
